@@ -22,6 +22,7 @@ USFB2="usr/share/$FB2DIR"
 VAR="var/lib/$FB2DIR"
 EMBED_SO_VER="${FB_MAJOR}.${FB_MINOR}"
 CLIENT_SO_VER=${FB_MAJOR}
+UTIL_SO_VER=
 
 
 copy ()
@@ -43,7 +44,7 @@ copy ()
 # Helper function used both in -super and -classic
 copy_utils()
 {
-    for s in gbak gdef gfix gpre qli gsec gstat isql nbackup;
+    for s in gbak gdef gfix gpre qli gsec gstat isql nbackup ;
     do
         target=$s
         if [ $target = gstat ];
@@ -54,8 +55,7 @@ copy_utils()
             target=isql-fb
         fi
 
-        copy e $D/$ULFB2/bin/$target.real $S/bin/$s
-        ln -s /$ULFB2/bin/wrapper $D/usr/bin/$target
+        copy e $D/usr/bin/$target $S/usr/bin/$s
     done
 }
 
@@ -75,17 +75,23 @@ make_super () {
     D=debian/$P
     S=debian/firebird-super
 
-    mkdir -p $D/usr/bin $D/$ULFB2/bin $D/$ULFB2/UDF
+    mkdir -p $D/usr/bin $D/usr/sbin $D/$ULFB2/UDF
 
-    for f in fbserver fbguard fb_lock_print fbmgr.bin; do
-        install -m 0755 $S/bin/$f $D/$ULFB2/bin/$f.real
-        ln -s wrapper $D/$ULFB2/bin/$f
-    done
+    copy e $D/usr/sbin              \
+        $S/usr/sbin/fb_lock_print   \
+        $S/usr/sbin/fbserver        \
 
-    copy e $D/$ULFB2/UDF $S/UDF/fbudf.so $S/UDF/ib_udf.so
+    copy e $D/usr/bin       \
+        $S/usr/bin/fbsvcmgr \
+        $S/usr/bin/fbtracemgr
+
+    copy e $D/$ULFB2/UDF \
+        $S/$ULFB2/UDF/fbudf.so $S/$ULFB2/UDF/ib_udf.so
 
     copy_utils
 
+    dh_installman -p $P debian/fbserver.1
+
     doc_symlink
 }
 
@@ -96,26 +102,65 @@ make_classic () {
     D=debian/$P
     S=debian/firebird-classic
 
-    mkdir -p $D/$ULFB2/bin      \
-            $D/$ULFB2/UDF       \
-            $D/usr/bin          \
-            $D/etc/xinetd.d
+    mkdir -p $D/usr/sbin    \
+             $D/etc/xinetd.d
 
-    for f in fb_inet_server fb_lock_mgr fb_lock_print gds_drop; do
-        install -m 0755 $S/bin/$f $D/$ULFB2/bin/$f.real
-        ln -s wrapper $D/$ULFB2/bin/$f
-    done
+    copy e $D/usr/sbin \
+        $S/usr/sbin/fb_inet_server
 
-    copy_utils
+    dh_installman -p $P debian/fb_inet_server.1
 
     install -m 0644 debian/$FB2-classic.xinetd \
     		    $D/etc/xinetd.d/$FB2_no_dots
 
-    copy e $D/$ULFB2/UDF $S/UDF/fbudf.so $S/UDF/ib_udf.so
+    doc_symlink
+}
+
+#-superclassic
+make_superclassic () {
+    P="$FB2-superclassic"
+    echo "Creating $P content"
+    D=debian/$P
+    S=debian/firebird-classic
+
+    mkdir -p $D/usr/sbin
+
+    copy e $D/usr/sbin \
+        $S/usr/sbin/fb_smp_server
+
+    dh_installman -p $P debian/fb_smp_server.1
 
     doc_symlink
 }
 
+#-classic-common
+make_classic_common () {
+    P="$FB2-classic-common"
+    echo "Creating $P content"
+    D=debian/$P
+    S=debian/firebird-classic
+
+    mkdir -p $D/$ULFB2/UDF      \
+             $D/usr/bin         \
+             $D/usr/sbin
+
+    copy e $D/usr/sbin \
+	$S/usr/sbin/fb_lock_print
+
+    copy e $D/usr/bin \
+	$S/usr/bin/fbsvcmgr
+
+    copy e $D/usr/bin \
+        $S/usr/bin/fbtracemgr
+
+    copy_utils
+
+    copy e $D/$ULFB2/UDF $S/$ULFB2/UDF/fbudf.so $S/$ULFB2/UDF/ib_udf.so
+
+    doc_symlink
+}
+
+
 #libfbclient
 make_libfbclient () {
     P="libfbclient$CLIENT_SO_VER"
@@ -125,7 +170,7 @@ make_libfbclient () {
 
     mkdir -p $D/usr/lib
 
-    copy e $D/usr/lib $S/lib/libfbclient.so.$FB_VERSION
+    copy e $D/usr/lib $S/usr/lib/libfbclient.so.$FB_VERSION
     ln -s libfbclient.so.$FB_VERSION $D/usr/lib/libfbclient.so.$CLIENT_SO_VER
 
     doc_symlink
@@ -140,12 +185,26 @@ make_libfbembed () {
 
     mkdir -p $D/usr/lib
 
-    copy e $D/usr/lib $S/lib/libfbembed.so.$FB_VERSION
+    copy e $D/usr/lib $S/usr/lib/libfbembed.so.$FB_VERSION
     ln -s libfbembed.so.$FB_VERSION $D/usr/lib/libfbembed.so.$EMBED_SO_VER
 
     doc_symlink
 }
 
+#libib-util
+make_libib_util () {
+    P="libib-util$UTIL_SO_VER"
+    echo "Creating $P content"
+    D=debian/$P
+    S=debian/firebird-super
+
+    mkdir -p $D/usr/lib
+
+    install -m 0755 $S/usr/lib/libib_util.so $D/usr/lib/
+
+    doc_symlink
+}
+
 
 #-server-common
 make_server_common () {
@@ -156,10 +215,12 @@ make_server_common () {
 
     mkdir -p $D/etc/$FB2DIR \
         $D/etc/logrotate.d \
+        $D/etc/default \
         $D/etc/$FB2DIR \
+        $D/usr/sbin \
         $D/$ULFB2 \
         $D/$ULFB2/UDF \
-        $D/$ULFB2/bin \
+        $D/$ULFB2/plugins \
         $D/$VAR \
         $D/$VAR/system \
         $D/$VAR/tmp \
@@ -168,7 +229,10 @@ make_server_common () {
         $D/$COMMON_DOC/examples
 
     copy f $D/etc/$FB2DIR \
-        $S/install/misc/aliases.conf
+        $S/etc/$FB2DIR/aliases.conf \
+        $S/etc/$FB2DIR/fbtrace.conf
+
+    cp debian/server.default $D/etc/default/firebird${FB_VER}
 
     # fix aliases.conf: employee.fdb should point to a database
     # in /$VAR/data where all databases live
@@ -179,18 +243,23 @@ make_server_common () {
     touch $D/$VAR/data/no_empty
 
     copy f $D/$ULFB2/UDF \
-        src/extlib/fbudf/fbudf.sql \
-        src/extlib/ib_udf.sql \
-        src/extlib/ib_udf2.sql
+        $S/$ULFB2/UDF/*.sql
+
+    copy e $D/usr/sbin              \
+	$S/usr/sbin/fbguard         \
+
+    copy f $D/$ULFB2/plugins    \
+        $S/$ULFB2/plugins/libfbtrace.so
 
     # databases
-    cp $S/security2.fdb \
-    $D/$VAR/system/default-security2.fdb
+    cp $S/$VAR/system/security2.fdb \
+        $D/$VAR/system/default-security2.fdb
 
-    copy f $D/$VAR/system $S/help/help.fdb
+    copy f $D/$VAR/system $S/$VAR/system/help.fdb
 
     # manpages
-    for u in fbstat gbak gdef gsec isql-fb gfix gpre qli nbackup ;
+    for u in fbstat gbak gdef gsec isql-fb gfix gpre qli nbackup fbsvcmgr \
+        fbtracemgr fbguard fb_lock_print ;
     do
         dh_installman -p $P debian/$u.1
     done
@@ -209,27 +278,25 @@ make_common () {
 
     mkdir -p \
         $D/etc/$FB2DIR \
-        $D/$ULFB2/intl $D/$ULFB2/bin \
+        $D/$ULFB2/intl \
         $D/$USFB2 \
         $D/usr/share/$P
 
     # config
-    copy f $D/etc/$FB2DIR $S/install/misc/firebird.conf
+    copy f $D/etc/$FB2DIR $S/etc/$FB2DIR/firebird.conf
 
     install -m 0644 -o root -g root \
         debian/functions.sh \
         $D/usr/share/$P/
 
-    for m in $S/*.msg;
+    for m in $S/$USFB2/*.msg;
     do
         copy f $D/$USFB2 $m
     done
 
-    copy f $D/etc/$FB2DIR/fbintl.conf $S/misc/fbintl.conf
+    copy f $D/etc/$FB2DIR/fbintl.conf $S/$ULFB2/intl/fbintl.conf
 
-    install -m 0064 $S/intl/libfbintl.so $D/$ULFB2/intl/fbintl.so
-
-    copy e $D/$ULFB2/bin debian/wrapper
+    install -m 0755 $S/$ULFB2/intl/fbintl $D/$ULFB2/intl/fbintl
 
     doc_symlink
 }
@@ -242,12 +309,15 @@ make_dev () {
     S=debian/firebird-super
 
     mkdir -p $D/usr/include \
-             $D/usr/lib/$DEB_HOST_MULTIARCH
+             $D/usr/lib
 
-    copy f $D/usr/include $S/include/*.h
+    copy f $D/usr/include $S/usr/include/*
 
-    ln -s libfbclient.so.$CLIENT_SO_VER $D/usr/lib/$DEB_HOST_MULTIARCH/libfbclient.so
-    ln -s libfbembed.so.$EMBED_SO_VER $D/usr/lib/$DEB_HOST_MULTIARCH/libfbembed.so
+    ln -s libfbclient.so.$CLIENT_SO_VER $D/usr/lib/libfbclient.so
+    ln -s libfbembed.so.$EMBED_SO_VER $D/usr/lib/libfbembed.so
+    if [ -n "$UTIL_SO_VER" ]; then
+        ln -s libib_utill.so.$UTIL_SO_VER $D/usr/lib/libib_util.so
+    fi
 
     doc_symlink
 }
@@ -261,7 +331,7 @@ make_examples () {
     S=debian/firebird-super
 
     mkdir -p $D/$COMMON_DOC
-    cp -r $S/examples $D/$COMMON_DOC
+    cp -r $S/$COMMON_DOC/examples $D/$COMMON_DOC
 
     install -m 0644 \
         debian/$P.README.Debian \
@@ -295,14 +365,18 @@ make_common_doc() {
 umask 022
 make_super
 make_classic
-#make_libfbclient
+make_superclassic
+make_classic_common
+make_libfbclient
 make_libfbembed
+make_libib_util
 make_common
 make_server_common
-#make_dev
-#P=firebird${FB_VER}-dev doc_symlink
+make_dev
 make_examples
 make_doc
 make_common_doc
+P=$FB2-super-dbg doc_symlink
+P=$FB2-classic-dbg doc_symlink
 echo "Packages ready."
 exit 0
